@@ -165,13 +165,13 @@ class KubeModel(ABC):
         """
         job_id = self.args._job_id
         func_id = self.args._func_id
-        self.logger.debug('loading file from host')
-
-        with open(f'/output/{job_id}:test:{func_id}.pkl', 'rb') as f:
-            self.logger.debug(f'loading file, epoch: {self.epoch}')
-            state = pickle.load(f)
-            self.logger.debug(f'file loaded, value: {state}')
-            print('file loaded')    
+        if os.path.isfile(f'/output/{job_id}:test:{func_id}.pkl'):
+            self.logger.debug('loading file from host')
+            with open(f'/output/{job_id}:test:{func_id}.pkl', 'rb') as f:
+                self.logger.debug(f'loading file, epoch: {self.epoch}')
+                state = pickle.load(f)
+                self.logger.debug(f'file loaded, value: {state}')
+                print('file loaded')    
 
     def _save_optimizer_redis(self):
         """
